@@ -1,17 +1,12 @@
 /*
  * See Licensing and Copyright notice in naev.h
  */
-
-
-
-#ifndef JOYSTICK_H
-#  define JOYSTICK_H
-
+#pragma once
 
 /*
  * gets the joystick index number based on its name
  */
-int joystick_get( const char* namjoystick );
+int joystick_get( const char *namjoystick );
 
 /*
  * sets the game to use the joystick of index indjoystick
@@ -21,8 +16,5 @@ int joystick_use( int indjoystick );
 /*
  * init/exit functions
  */
-int joystick_init (void);
-void joystick_exit (void);
-
-
-#endif /* JOYSTICK_H */
+int  joystick_init( void );
+void joystick_exit( void );
