@@ -1,29 +1,19 @@
 /*
  * See Licensing and Copyright notice in naev.h
  */
-
 /**
  * @file nlua_cli.c
  *
  * @brief Contains Lua bindings for the console.
  */
+/** @cond */
+#include <lauxlib.h>
+/** @endcond */
 
 #include "nlua_cli.h"
 
-#include "naev.h"
-
-#include <lauxlib.h>
-
-#include "nluadef.h"
-#include "log.h"
-#include "mission.h"
-
-
 /* CLI */
-static const luaL_Reg cli_methods[] = {
-   {0,0}
-}; /**< CLI Lua methods. */
-
+static const luaL_Reg cli_methods[] = { { 0, 0 } }; /**< CLI Lua methods. */
 
 /**
  * @brief Loads the CLI Lua library.
@@ -33,7 +23,6 @@ static const luaL_Reg cli_methods[] = {
  */
 int nlua_loadCLI( nlua_env env )
 {
-   nlua_register(env, "cli", cli_methods, 0);
+   nlua_register( env, "cli", cli_methods, 0 );
    return 0;
 }
-
