@@ -12,33 +12,26 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-
-
-#ifndef THREADPOOL_H
-#  define THREADPOOL_H
-
+#pragma once
 
 struct ThreadQueue_;
 typedef struct ThreadQueue_ ThreadQueue;
 
-
 /* Initializes the threadpool */
 int threadpool_init( void );
 
-/* Enqueues a new job */
-int threadpool_newJob( int (*function)(void *), void *data );
-
-/* Creates a new vpool queue */
-ThreadQueue* vpool_create( void );
+/* Creates a new vpool queue. Destroy with vpool_wait. */
+ThreadQueue *vpool_create( void );
 
 /* Enqueue a job in the vpool queue. Do NOT enqueue a job that has to wait for
- * another job to be done as this could lead to a deadlock. */
-void vpool_enqueue( ThreadQueue* queue, int (*function)(void *), void *data );
+ * another job to be done as this could lead to a deadlock. Also do not enqueue
+ * jobs from enqueued threads. */
+void vpool_enqueue( ThreadQueue *queue, int ( *function )( void * ),
+                    void        *data );
 
-/* Run every job in the vpool queue and block untill every job in the queue is
- * done. It destroys the queue when it's done. */
-void vpool_wait( ThreadQueue* queue );
+/* Run every job in the vpool queue and block until every job in the queue is
+ * done. */
+void vpool_wait( ThreadQueue *queue );
 
-
-
-#endif
+/* Clean up. */
+void vpool_cleanup( ThreadQueue *queue );
