@@ -16,11 +16,12 @@
 #include "tk/toolkit_priv.h"
 
 static Widget *chk_getWgt( unsigned int wid, const char *name );
-static int chk_key( Widget* chk, SDL_Keycode key, SDL_Keymod mod, int isrepeat );
-static int chk_mclick( Widget* chk, int button, int x, int y );
-static void chk_render( Widget* chk, double bx, double by );
-static void chk_cleanup( Widget* chk );
-static void chk_toggleState( Widget *chk );
+static int     chk_key( Widget *chk, SDL_Keycode key, SDL_Keymod mod,
+                        int isrepeat );
+static int     chk_mclick( Widget *chk, int button, int x, int y );
+static void    chk_render( Widget *chk, double bx, double by );
+static void    chk_cleanup( Widget *chk );
+static void    chk_toggleState( Widget *chk );
 
 /**
  * @brief Adds a button widget to a window.
@@ -38,34 +39,34 @@ static void chk_toggleState( Widget *chk );
  *    @param call Function to call when checkbox is toggled Parameter passed
  *                is the name of the checkbox.
  */
-void window_addCheckbox( unsigned int wid,
-      const int x, const int y, /* position */
-      const int w, const int h, /* size */
-      const char* name, const char* display, /* label name, display name */
-      void (*call) (unsigned int,const char*), /* toggle function */
-      int default_state ) /* default state. */
+void window_addCheckbox(
+   unsigned int wid, const int x, const int y,   /* position */
+   const int w, const int h,                     /* size */
+   const char *name, const char *display,        /* label name, display name */
+   void ( *call )( unsigned int, const char * ), /* toggle function */
+   int default_state )                           /* default state. */
 {
-   Window *wdw = window_wget(wid);
-   Widget *wgt = window_newWidget(wdw, name);
-   if (wgt == NULL)
+   Window *wdw = window_wget( wid );
+   Widget *wgt = window_newWidget( wdw, name );
+   if ( wgt == NULL )
       return;
 
    /* generic */
    wgt->type = WIDGET_CHECKBOX;
 
    /* specific */
-   wgt->keyevent           = chk_key;
-   wgt->mclickevent        = chk_mclick;
-   wgt->render             = chk_render;
-   wgt->cleanup            = chk_cleanup;
-   wgt->dat.chk.display    = (display == NULL) ? NULL : strdup(display);
-   wgt->dat.chk.fptr       = call;
-   wgt->dat.chk.state      = default_state;
-   wgt->dat.chk.disabled   = 0;
+   wgt->keyevent         = chk_key;
+   wgt->mclickevent      = chk_mclick;
+   wgt->render           = chk_render;
+   wgt->cleanup          = chk_cleanup;
+   wgt->dat.chk.display  = ( display == NULL ) ? NULL : strdup( display );
+   wgt->dat.chk.fptr     = call;
+   wgt->dat.chk.state    = default_state;
+   wgt->dat.chk.disabled = 0;
 
    /* position/size */
-   wgt->w = (double) w;
-   wgt->h = (double) h;
+   wgt->w = (double)w;
+   wgt->h = (double)h;
    toolkit_setPos( wdw, wgt, x, y );
 }
 
@@ -74,13 +75,13 @@ void window_addCheckbox( unsigned int wid,
  */
 static Widget *chk_getWgt( unsigned int wid, const char *name )
 {
-   Widget *wgt = window_getwgt(wid,name);
-   if (wgt == NULL)
+   Widget *wgt = window_getwgt( wid, name );
+   if ( wgt == NULL )
       return NULL;
 
    /* Check type. */
-   if (wgt->type != WIDGET_CHECKBOX) {
-      DEBUG("Calling checkbox function on non-checkbox widget '%s'", name);
+   if ( wgt->type != WIDGET_CHECKBOX ) {
+      DEBUG( "Calling checkbox function on non-checkbox widget '%s'", name );
       return NULL;
    }
 
@@ -96,12 +97,12 @@ static Widget *chk_getWgt( unsigned int wid, const char *name )
  */
 void window_checkboxCaption( unsigned int wid, const char *name, char *display )
 {
-   Widget *wgt = chk_getWgt(wid, name);
-   if (wgt == NULL)
+   Widget *wgt = chk_getWgt( wid, name );
+   if ( wgt == NULL )
       return;
 
-   free(wgt->dat.chk.display);
-   wgt->dat.chk.display = strdup(display);
+   free( wgt->dat.chk.display );
+   wgt->dat.chk.display = strdup( display );
 }
 
 /**
@@ -111,8 +112,8 @@ void window_checkboxCaption( unsigned int wid, const char *name, char *display )
  */
 int window_checkboxState( unsigned int wid, const char *name )
 {
-   Widget *wgt = chk_getWgt(wid, name);
-   if (wgt == NULL)
+   Widget *wgt = chk_getWgt( wid, name );
+   if ( wgt == NULL )
       return -1;
 
    return wgt->dat.chk.state;
@@ -126,8 +127,8 @@ int window_checkboxState( unsigned int wid, const char *name )
  */
 int window_checkboxSet( unsigned int wid, const char *name, int state )
 {
-   Widget *wgt = chk_getWgt(wid, name);
-   if (wgt == NULL)
+   Widget *wgt = chk_getWgt( wid, name );
+   if ( wgt == NULL )
       return -1;
 
    wgt->dat.chk.state = state;
@@ -140,7 +141,7 @@ int window_checkboxSet( unsigned int wid, const char *name, int state )
 static void chk_toggleState( Widget *chk )
 {
    chk->dat.chk.state = !chk->dat.chk.state;
-   if (chk->dat.chk.fptr != NULL)
+   if ( chk->dat.chk.fptr != NULL )
       chk->dat.chk.fptr( chk->wdw, chk->name );
 }
 
@@ -153,15 +154,15 @@ static void chk_toggleState( Widget *chk )
  *    @param isrepeat Whether or not the key is repeating.
  *    @return 1 if the event was used, 0 if it wasn't.
  */
-static int chk_key( Widget* chk, SDL_Keycode key, SDL_Keymod mod, int isrepeat )
+static int chk_key( Widget *chk, SDL_Keycode key, SDL_Keymod mod, int isrepeat )
 {
-   (void) mod;
-   (void) isrepeat;
+   (void)mod;
+   (void)isrepeat;
 
-   if (chk->dat.chk.disabled)
+   if ( chk->dat.chk.disabled )
       return 0;
 
-   if (key == SDLK_SPACE)
+   if ( key == SDLK_SPACE )
       chk_toggleState( chk );
 
    return 0;
@@ -170,13 +171,13 @@ static int chk_key( Widget* chk, SDL_Keycode key, SDL_Keymod mod, int isrepeat )
 /**
  * @brief Handles checkbox mouse clicks.
  */
-static int chk_mclick( Widget* chk, int button, int x, int y )
+static int chk_mclick( Widget *chk, int button, int x, int y )
 {
-   (void) button;
-   (void) y;
-   if (chk->dat.chk.disabled)
+   (void)button;
+   (void)y;
+   if ( chk->dat.chk.disabled )
       return 0;
-   if ((x > 0) && (x <= chk->w) && (y > 0) && (y <= chk->h))
+   if ( ( x > 0 ) && ( x <= chk->w ) && ( y > 0 ) && ( y <= chk->h ) )
       chk_toggleState( chk );
    return 1;
 }
@@ -188,35 +189,35 @@ static int chk_mclick( Widget* chk, int button, int x, int y )
  *    @param bx Base X position.
  *    @param by Base Y position.
  */
-static void chk_render( Widget* chk, double bx, double by )
+static void chk_render( Widget *chk, double bx, double by )
 {
    const glColour *cbkg, *cfg;
-   double x, y;
+   double          x, y;
 
    x = bx + chk->x;
    y = by + chk->y;
 
    /* set the colours */
-   if (chk->dat.chk.disabled) {
-      cbkg  = toolkit_col;
-      cfg   = &cFontGrey;
-   }
-   else {
-      cbkg  = toolkit_colLight;
-      cfg   = &cFontWhite;
+   if ( chk->dat.chk.disabled ) {
+      cbkg = toolkit_col;
+      cfg  = &cFontGrey;
+   } else {
+      cbkg = toolkit_colLight;
+      cfg  = &cFontWhite;
    }
 
    /* Draw rect. */
-   toolkit_drawRect( x-1, y-1 + (chk->h-10.)/2., 12., 12., toolkit_colDark, NULL );
-   toolkit_drawRect( x, y + (chk->h-10.)/2., 10., 10., cbkg, NULL );
-   if (chk->dat.chk.state)
-      toolkit_drawRect( x+2., y+2. + (chk->h-10.)/2., 6., 6., toolkit_colDark, NULL );
+   toolkit_drawRect( x - 1, y - 1 + ( chk->h - 10. ) / 2., 12., 12.,
+                     toolkit_colDark, NULL );
+   toolkit_drawRect( x, y + ( chk->h - 10. ) / 2., 10., 10., cbkg, NULL );
+   if ( chk->dat.chk.state )
+      toolkit_drawRect( x + 2., y + 2. + ( chk->h - 10. ) / 2., 6., 6.,
+                        toolkit_colDark, NULL );
 
    /* Draw the txt. */
-   gl_printMaxRaw( NULL, chk->w - 20,
-         bx + chk->x + 15,
-         by + chk->y + (chk->h - gl_defFont.h)/2.,
-         cfg, -1., chk->dat.chk.display );
+   gl_printMaxRaw( NULL, chk->w - 20, bx + chk->x + 15,
+                   by + chk->y + ( chk->h - gl_defFont.h ) / 2., cfg, -1.,
+                   chk->dat.chk.display );
 }
 
 /**
@@ -226,8 +227,8 @@ static void chk_render( Widget* chk, double bx, double by )
  */
 static void chk_cleanup( Widget *chk )
 {
-   if (chk->dat.chk.display != NULL)
-      free(chk->dat.chk.display);
+   if ( chk->dat.chk.display != NULL )
+      free( chk->dat.chk.display );
 }
 
 /**
@@ -238,8 +239,8 @@ static void chk_cleanup( Widget *chk )
  */
 int window_enableCheckbox( unsigned int wid, const char *name )
 {
-   Widget *wgt = chk_getWgt(wid, name);
-   if (wgt == NULL)
+   Widget *wgt = chk_getWgt( wid, name );
+   if ( wgt == NULL )
       return -1;
    wgt->dat.chk.disabled = 0;
    return 0;
@@ -253,8 +254,8 @@ int window_enableCheckbox( unsigned int wid, const char *name )
  */
 int window_disableCheckbox( unsigned int wid, const char *name )
 {
-   Widget *wgt = chk_getWgt(wid, name);
-   if (wgt == NULL)
+   Widget *wgt = chk_getWgt( wid, name );
+   if ( wgt == NULL )
       return -1;
    wgt->dat.chk.disabled = 1;
    return 0;
